/**
 * External dependencies
 */
import classnames from 'classnames';
import { unescape } from 'lodash';

/**
 * WordPress dependencies
 */
import {
	AlignmentToolbar,
	InspectorControls,
	BlockControls,
	useBlockProps,
	ColorPalette,
} from '@wordpress/block-editor';
import {
	Spinner,
	TextControl,
	ToggleControl,
	RangeControl,
	Panel,
	PanelBody,
	SelectControl,
	FormTokenField

} from '@wordpress/components';
import { useSelect } from '@wordpress/data';
import { __ } from '@wordpress/i18n';
import { store as coreStore } from '@wordpress/core-data';
import ServerSideRender from '@wordpress/server-side-render';
/**
 * Internal dependencies
 */
import usePostTerms from './use-post-terms';

export default function Edit(props) {
	const attributes = props.attributes;
	const context = props.context;
	const setAttributes = props.setAttributes;
	const { term, textAlign, separator, selectedTax } = attributes;
	const { postId, postType } = context;
	const ctaxblock = window.ctaxblock
	const taxonomies = ctaxblock.taxPerPt[postType]
	const selectedTerm = useSelect(
		(select) => {
			if (!term) return {};
			const { getTaxonomy } = select(coreStore);
			const taxonomy = getTaxonomy(term);
			return taxonomy?.visibility?.publicly_queryable ? taxonomy : {};
		},
		[term]
	);
	const { postTerms, hasPostTerms, isLoading } = usePostTerms({
		postId,
		postType,
		term: selectedTerm,
	});
	const hasPost = postId && postType;
	const blockProps = useBlockProps({
		className: classnames({
			[`has-text-align-${textAlign}`]: textAlign,
			[`taxonomy-${term}`]: term,
		}),
	});
	// if (!hasPost || !term) {
	// 	return <div {...blockProps}>{__('Post Terms')}</div>;
	// }

	return (
		<div {...useBlockProps()}>
			<BlockControls>

			</BlockControls>
			<InspectorControls key="setting">
				<Panel>
					<PanelBody title={__('Configurações do bloco')}>

						<TextControl
							autoComplete="off"
							label={__('Separator')}
							value={separator || ''}
							onChange={(nextValue) => {
								setAttributes({ separator: nextValue });
							}}
							help={__('Enter character(s) used to separate terms.')}
						/>
						<FormTokenField
							value={selectedTax || ''}
							suggestions={taxonomies}
							onChange={(nextValue) => {
								setAttributes({ selectedTax: nextValue });
							}}
						/>
					</PanelBody>
				</Panel>
			</InspectorControls>
			termos de taxonomia
		</div>
	);
}