/**
 * WordPress components that create the necessary UI elements for the block
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-components/
 */
import { TextControl } from '@wordpress/components';

/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-block-editor/#useBlockProps
 */
import { useBlockProps } from '@wordpress/block-editor';

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @see https://developer.wordpress.org/block-editor/developers/block-api/block-edit-save/#edit
 *
 * @param {Object}   props               Properties passed to the function.
 * @param {Object}   props.attributes    Available block attributes.
 * @param {Function} props.setAttributes Function that updates individual attributes.
 *
 * @return {WPElement} Element to render.
 */
export default function Edit( { attributes, setAttributes } ) {
	const blockProps = useBlockProps();
	return (
		<>
			<TextControl
				label="Título da galeria"
				value={ attributes.gallery_title }
				onChange={ ( val ) => setAttributes( { gallery_title: val } ) }
			/>
			<TextControl
				label="API Key"
				value={ attributes.api_key }
				onChange={ ( val ) => setAttributes( { api_key: val } ) }
			/>
			<TextControl
				label="ID do álbum"
				value={ attributes.album_id }
				onChange={ ( val ) => setAttributes( { album_id: val } ) }
			/>
		</>
	);
}
