import { __ } from '@wordpress/i18n'
import { useCallback, useEffect, useMemo, useState } from 'react'

import List from './List'

import { language, initialRequestPosts, statesCities } from '../hooks/globals'

const baseUrl = window.location.origin
const apiCacheVersion = window.geoInfoCacheVersion;

export default function Filter({ title }) {

    const [ posts, setPosts ] = useState([])
    const [ stateUf, setStateUf ] = useState(0)
    const [ city, setCity ] = useState(0)
    const [filterTermId, setFilterTermId] = useState(false)

    const setStateUfId = useCallback((e) => {
        setStateUf(Number(e.target.value))
        setCity(0)
        console.log( e );
    }, [setStateUf])

    const setCityId = useCallback((e) => {
        setCity(Number(e.target.value))
    }, [setCity])

    const setTermId = useCallback((e) => {
        setOrganizations([])
        setFilterTermId(city ? city : stateUf)
    }, [city, stateUf])

    const [ doneLoadingPosts, setDoneLoadingPosts ] = useState(false)

    const apiUrl = useMemo(() => {

        setPosts([])
        let url = ''
        

        url = new URL(`${baseUrl}/wp-json/wp/v2/testemunho`)
    
        if (filterTermId && typeof filterTermId != 'object' ) {
            url.searchParams.set('estadoscidades', filterTermId)
        }
        url.searchParams.set('apicv', apiCacheVersion)
        url.toString()
    
        return url

    }, [filterTermId])
    

    useEffect(() => {

        if (apiUrl) {
            const targetURL = new URL(`${apiUrl}`)
            const queryParams = { lang: language, per_page: 100 }
            Object.keys(queryParams).forEach(key => targetURL.searchParams.append(key, queryParams[key]))
    
            // Set loading
            setDoneLoadingPosts(false);
    
            // Fetch posts based on params
            fetch(targetURL)
                .then((response) => {
                    return response.json()
                })
                .then(data => {
                    setPosts([...posts, ...data])
                    return [...posts, ...data]
                })
                .catch(err => {
                    console.log( err )
                    console.log(err);
                })
                .then( () => {
                    setDoneLoadingPosts(true)
                })
        }

    }, [apiUrl] )

    return (
        <>
        { ( (doneLoadingPosts || posts.length > 0) && posts.length !== 0) &&
            <>
                <List _posts={ posts } title={ title } />
            </>
        }
        </>
    )

}
