import { useEffect, useState } from 'react'

const cache = new Map()

export function useFetch (url, options, deps) {
    const [data, setData] = useState(null)
    const [headers, setHeaders] = useState({})
    const [error, setError] = useState(null)
    const [loading, setLoading] = useState(true)

    const urlObj = new URL(url);
    const searchParams = urlObj.searchParams;

    Object.keys(options).forEach( (paramKey) => {
        const paramValue = options[paramKey];
        searchParams.set( paramKey,  paramValue );
    } );

    useEffect(() => {
        if (cache.has(url)) {
            setData(cache.get(url))
            setHeaders(cache.get(`${url}_headers`))
            setError(null)
            setLoading(false)

        } else {
            const fetchData = async () => {
                setLoading(true)
                try {
                    const res = await fetch(urlObj, options)
                    const json = await res.json()
                    
                    const headers = {}
                    for (let [key, value] of res.headers) {
                        headers[key] = value;
                    }

                    setHeaders(headers)
                    setData(json)
                    setLoading(false)

                    cache.set(url, json)
                    cache.set(`${url}_headers`, headers)
                } catch (error) {
                    setError(error)
                    setLoading(false)
                }
            }
            fetchData()
        }
    }, deps)

    return { data, error, loading, headers }
}
