import { useCallback, useEffect } from 'react'

export function updateQuery (updatedParams) {
    const { host, pathname, protocol, search } = window.location
    const searchParams = new URLSearchParams(search)
    for (let [key, value] of Object.entries(updatedParams)) {
        if (value == null) {
            searchParams.delete(key)
        } else {
            searchParams.set(key, value)
        }
    }
    const newUrl = `${protocol}//${host}${pathname}?${searchParams.toString()}`
    if (newUrl !== window.location.href) {
        window.history.pushState({ path: newUrl }, '', newUrl)
    }
}

function buildHistoryPayload (event) {
    return {
        params: new URLSearchParams(window.history.state?.newUrl ?? window.location.search),
        state: event?.state ?? null,
    }
}

export function useHistory (callback, deps) {
    const onPop = useCallback((event) => {
        callback(buildHistoryPayload(event))
    }, deps)

    useEffect(() => {
        onPop(null)
        window.addEventListener('popstate', onPop)
        return () => window.removeEventListener('popstate', onPop)
    }, [onPop])
}
