<?php

namespace hacklabBlocks;

/**
 * Server-side rendering of the `hacklab-blocks/post-meta` block.
 *
 * @package WordPress
 */

/**
 * Renders the `hacklab-blocks/post-meta` block on the server.
 *
 * @param array    $attributes Block attributes.
 * @param string   $content    Block default content.
 * @param WP_Block $block      Block instance.
 * @return string Returns the filtered post terms for the current post wrapped inside "a" tags.
 */

add_action('admin_enqueue_scripts', 'hacklabBlocks\\post_meta_admin_enqueue');

function post_meta_admin_enqueue()
{
	$args = array(
		'public'   => true,
	);

	$taxonomies = get_taxonomies($args, 'objects');
	$tax_per_pt = [];
	foreach ($taxonomies as $taxonomy) {
		$post_types = $taxonomy->object_type;
		foreach ($post_types as $post_type) {
			if (!isset($tax_per_pt[$post_type])) {
				$tax_per_pt[$post_type] = [];
			}
			$tax_per_pt[$post_type][] =  $taxonomy->name;
		}
	}
	wp_localize_script('hacklab-blocks-post-meta-editor-script', 'ctaxblock', [
		'taxonomies' => $taxonomies,
		'taxPerPt' => $tax_per_pt
	]);
}
function post_meta_callback($attributes, $content, $block)
{
	if (!isset($block->context['postId']) || !isset($attributes['selectedMeta'])) {
		return '';
	}
	$classes = '';
	$metadata = [];
	foreach ($attributes['selectedMeta'] as $meta) {
		$metadata[]= get_post_meta( $block->context['postId'], $meta, true );
	}
	$html = '';
	if(count($metadata)){
	$html .= '<div class="post-meta">';
		$separator = empty($attributes['separator']) ? ' ' : $attributes['separator'];
		$html_array = [];
		foreach ($metadata as $meta) {
			$html_array[]= $meta;
		}
		
		$html = implode($separator, $html_array);
		$html .= '</div>';
	}
	return $html;
}
