<?php
namespace hacklabBlocks;

/**
 * Story list render_callback
 */

function story_list_callback( $attributes, $content, $block ) {

    $bg_color      = ( ! empty( $attributes['bg_color'] ) ) ? $attributes['bg_color'] : 'transparent';
    $heading_color = ( ! empty( $attributes['text_color'] ) ) ? $attributes['text_color'] : '#902424';
    $text_color    = ( ! empty( $attributes['text_color'] ) ) ? $attributes['text_color'] : '#000000';
    $term_id       = ( ! empty( $attributes['term_id'] ) ) ? $attributes['term_id'] : '';

    $term = get_term_by( 'term_id', $term_id, 'tipo' );
    $term_slug = ( is_object( $term ) ) ? 'term-' . $term->slug : 'default'; 

    $args = [
        'post_type' => 'relato',
        'posts_per_page' => 100
    ];

    if ( $term_id ) {
        $args['tax_query'] = [
            [
                'taxonomy' => 'tipo',
                'terms' => $term_id,
            ]
        ];
    }

    $stories = get_posts( $args );

    $title = isset( $attributes['title'] ) ? $attributes['title'] : '';
    $description = isset( $attributes['description'] ) ? $attributes['description'] : '';

    $html = '<div class="wp-block-hacklab-story-list ' . $term_slug . '" style="background-color: ' . $bg_color . '; color: ' . $text_color . ';">';

    if ( $title ) {
        $html .= '<h2 class="block-title" style="color: ' . $heading_color . ';">' . $title . '</h2>';
    }

    if ( $description ) {
        $html .= '<span class="block-description" style="color: ' . $text_color . ';">' . $description . '</span>';
    }

    $html .= '<div class="wp-block-hacklab-story-list__content">';
    $html .= '<span class="close"></span>';
    $html .= '<span class="nav nav-prev">Anterior</span>';
    $html .= '<span class="nav nav-next">Próximo</span>';

    if ( $stories ) {

        $count_stories = count( $stories );
        $prev = $stories[$count_stories - 1]->ID;

        foreach ( $stories as $key => $story ) {

            if ( $key == ( $count_stories - 1 )) {
                $next = $stories[0]->ID;
            } else {
                $next = $stories[$key + 1]->ID;
            }

            $html .= '<article data-story=' . $story->ID  . ' data-prev=' . $prev . ' data-next=' . $next . ' class="story-item story-' . $story->ID . '">';
            $html .= '<div class="thumbnail">';
            $html .= get_the_post_thumbnail( $story->ID, 'thumbnail' );
            $html .= '</div>';
            $html .= '<h3 class="title" style="color: ' . $text_color . ';">';
            $html .= $story->post_title;
            $html .= '</h3>';
            $html .= '<div class="description">';
            $html .= '<h3 class="title">';
            $html .= $story->post_title;
            $html .= '</h3>';
            $html .= apply_filters('the_content', $story->post_content );
            $html .= '</div>';
            $html .= '</article>';

            $prev = $story->ID;
        }
    } else {
        $html .= '<h2>Nenhum relato para exibir.</h2>';
    }

    $html .= '</div>';
    $html .= '</div>';

    wp_reset_postdata();

    return $html;

}

add_action( 'wp_enqueue_scripts', 'hacklabBlocks\\story_list_enqueue' );

function story_list_enqueue() {
    wp_enqueue_script( 'story-list', plugin_dir_url( __FILE__ ) . 'script.js', [], time(), true );
}

add_action( 'admin_enqueue_scripts', 'hacklabBlocks\\story_list_admin_enqueue' );

function story_list_admin_enqueue() {

    $terms = get_terms( [
        'taxonomy'   => 'tipo',
        'hide_empty' => true,
    ] );

    $termsOptions = [];
    $termsOptions[] = [
        'value' => '',
        'label' => 'Selecione'
    ];

    foreach ( $terms as $term ) {
        $termsOptions[] = [
            'value' => $term->term_id,
            'label' => $term->name
        ];
    }

    wp_localize_script( 'hacklab-blocks-story-list-editor-script', 'storyList', [
        'taxonomy' => 'tipo',
        'terms'    => $termsOptions
    ] );

}