/**
 * WordPress components that create the necessary UI elements for the block
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-components/
 */

import { TextControl, SelectControl, __experimentalNumberControl as NumberControl } from '@wordpress/components';
import { __ } from "@wordpress/i18n";

import React, {useCallback , useSelect, useState, useEffect } from 'react';
/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-block-editor/#useBlockProps
 */
import { useBlockProps } from '@wordpress/block-editor';

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @see https://developer.wordpress.org/block-editor/developers/block-api/block-edit-save/#edit
 *
 * @param {Object}   props               Properties passed to the function.
 * @param {Object}   props.attributes    Available block attributes.
 * @param {Function} props.setAttributes Function that updates individual attributes.
 *
 * @return {WPElement} Element to render.
 */
 import apiFetch from '@wordpress/api-fetch';
 
 // GET

 export default function Edit( { 
	 attributes: {
		 title,
		 youtubeFormat,
		 youtubeId,
		 numItems,
		 style
		},
		setAttributes } ) {
	
	const [youtubeKey, setyoutubeKey] = useState('');
	useEffect(() => {
		apiFetch( { path: 'hacklab-blocks/v1/options/' } ).then( ( option ) => {	
			setyoutubeKey(option);
		} );
	},
	[]);	
	return (
		<>
		{  ! youtubeKey  ? 
            <div>Preencha a chave do youtube nas configurações para utilizar o bloco video-playlist</div>
         : 
			<div className="video-gallery-wrapper" key="container">
				<div>
					<TextControl
						label="Título"
						value={ title }
						onChange={ ( title ) => {
							setAttributes( { title } )
						} }
					/>

					<NumberControl
								label="Quantidade de videos"
								isShiftStepEnabled={ true }
								onChange={ ( numItems ) => {
									setAttributes( { numItems } )
								} }
								min={3}
								shiftStep={ 1 }
								value={ numItems }
					/>

					<SelectControl
						label="Formato do Youtube"
						value={ youtubeFormat }
						options={ [
							{ label: 'Canal', value: 'channel' },
							{ label: 'Playlist', value: 'playlist' },
						] }
						onChange={ ( youtubeFormat ) => {
							setAttributes( { youtubeFormat } )
						} }
					/>

					<TextControl
						label="ID do Canal/Playlist"
						value={ youtubeId }
						onChange={ ( youtubeId ) => {
							setAttributes( { youtubeId } )
						} }
					/>

					<SelectControl
								label="Estilo"
								value={ style }
								options={ [
									{ label: 'Sidebar', value: 'sidebar' },
									{ label: 'Bloco', value: 'block' },
								] }
								onChange={ ( style ) => {
									setAttributes( { style } )
								} }
							/>
					
				</div>
			</div>
			}
		
		</>
	);
}
